@@ -2,8 +2,9 @@ from maggma.api.resource import ReadOnlyResource
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 
-from emmet.core.alloys import AlloyPairDoc, AlloySystemDoc
+from emmet.core.alloys import AlloyPairDoc
 
+from emmet.api.core.settings import MAPISettings
 from emmet.api.routes.alloys.query_operators import (
     MaterialIDsSearchQuery,
     FormulaSearchQuery,
@@ -23,6 +24,7 @@ def alloy_pairs_resource(alloy_pairs_store):
         ],
         tags=["Alloys"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
